Struct protobuf::ProtobufEnumOrUnknown [−][src]
#[repr(transparent)]pub struct ProtobufEnumOrUnknown<E> { /* fields omitted */ }Expand description
Protobuf enums with possibly unknown values are preserved in this struct.
Implementations
Construct from any i32 value.
Note passed value is not required to be a valid enum value.
Construct from typed enum
Get i32 value as typed enum. Return None is value is unknown.
Get i32 value as typed enum.
Return default enum value (first value) if value is unknown.
Get i32 value as typed enum.
Return given enum value if value is unknown.
Get enum descriptor by type.